@@ -5,8 +5,8 @@ with 'Search::Elasticsearch::Role::Cxn::HTTP',
     'Search::Elasticsearch::Role::Cxn',
     'Search::Elasticsearch::Role::Is_Sync';
 
-use Search::Elasticsearch 1.17;
-our $VERSION = "1.17";
+use Search::Elasticsearch 1.19;
+our $VERSION = "1.19";
 
 use HTTP::Parser::XS qw(HEADERS_AS_HASHREF parse_http_response);
 use Try::Tiny;
@@ -42,14 +42,15 @@ sub perform_request {
     my $handle = $self->handle;
     $handle->reset;
 
-    #        $handle->setopt( CURLOPT_VERBOSE,     1 );
+    # $handle->setopt( CURLOPT_VERBOSE,     1 );
 
     $handle->setopt( CURLOPT_HEADER,        0 );
     $handle->setopt( CURLOPT_TCP_NODELAY,   1 );
     $handle->setopt( CURLOPT_URL,           $uri );
     $handle->setopt( CURLOPT_CUSTOMREQUEST, $method );
 
-    $handle->setopt( CURLOPT_CONNECTTIMEOUT_MS, $self->connect_timeout * 1000 );
+    $handle->setopt( CURLOPT_CONNECTTIMEOUT_MS,
+        $self->connect_timeout * 1000 );
     $handle->setopt( CURLOPT_TIMEOUT_MS,
         1000 * ( $params->{timeout} || $self->request_timeout ) );
 
@@ -75,7 +76,9 @@ sub perform_request {
         else {
             %opts = (
                 %opts,
-                ( CURLOPT_SSL_VERIFYPEER => 0, CURLOPT_SSL_VERIFYHOST => 0 )
+                (   CURLOPT_SSL_VERIFYPEER() => 0,
+                    CURLOPT_SSL_VERIFYHOST() => 0
+                )
             );
         }
     }
@@ -120,6 +123,7 @@ sub error_from_text {
     return
           m/^7:/  ? 'Cxn'
         : m/^28:/ ? 'Timeout'
+        : m/^51:/ ? 'SSL'
         : m/^55:/ ? 'ContentLength'
         :           'Request';
 
@@ -145,7 +149,7 @@ Search::Elasticsearch::Cxn::NetCurl - A Cxn implementation which uses libcurl vi
 
 =head1 VERSION
 
-version 1.17
+version 1.19
 
 =head1 DESCRIPTION
 
@@ -225,6 +229,9 @@ and to avoid man-in-the-middle attacks, you could do the following:
         }
     );
 
+If the remote server cannot be verified, an
+L<Search::Elasticsearch::Error|SSL error> will be thrown.
+
 If you want your client to present its own certificate to the remote
 server, then use:
 
@@ -382,7 +389,7 @@ Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Elasticsearch BV.
+This software is Copyright (c) 2015 by Elasticsearch BV.
 
 This is free software, licensed under:
 
